﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Microsoft.WindowsAzure.ServiceRuntime;
using Microsoft.WindowsAzure;
using Microsoft.WindowsAzure.StorageClient;

namespace NetflixPivot_Web.Controllers
{
    public class HomeController : Controller
    {
        private Uri GetBlobOrCdnUri(CloudBlob blob, string cdnHost)
        {
            // always use HTTP to avoid Silverlight cross-protocol issues
            var ub = new UriBuilder(blob.Uri)
            {
                Scheme = "http",
                Port = 80
            };
            if (!string.IsNullOrEmpty(cdnHost))
            {
                ub.Host = cdnHost;
            }
            return ub.Uri;
        }

        public ActionResult Index()
        {
            var blobs = CloudStorageAccount.Parse(RoleEnvironment.GetConfigurationSettingValue("DataConnectionString")).CreateCloudBlobClient();
            var cdnHost = RoleEnvironment.GetConfigurationSettingValue("CdnHost");

            var controlBlob = blobs.GetBlobReference("control/NetflixPivotViewer.xap");
            var collectionBlob = blobs.ListBlobsWithPrefix("collection/collection-").OfType<CloudBlob>().Where(b => b.Uri.AbsolutePath.EndsWith(".cxml")).First();

            ViewData["xapUrl"] = GetBlobOrCdnUri(controlBlob, cdnHost).AbsoluteUri;
            ViewData["collectionUrl"] = GetBlobOrCdnUri(collectionBlob, cdnHost).AbsoluteUri;
            return View();
        }

        public ActionResult About()
        {
            return View();
        }
    }
}
